@@ -37,6 +37,7 @@ class QPlatformMediaDevices;
 class QPlatformMediaCaptureSession;
 class QPlatformMediaPlayer;
 class QPlatformAudioDecoder;
+class QPlatformAudioResampler;
 class QPlatformCamera;
 class QPlatformSurfaceCapture;
 class QPlatformMediaRecorder;
@@ -53,8 +54,9 @@ class QPlatformVideoDevices;
 class QCapturableWindow;
 class QPlatformCapturableWindows;
 
-class Q_MULTIMEDIA_EXPORT QPlatformMediaIntegration
+class Q_MULTIMEDIA_EXPORT QPlatformMediaIntegration : public QObject
 {
+    Q_OBJECT
     inline static const QString notAvailable = QStringLiteral("Not available");
 public:
     static QPlatformMediaIntegration *instance();
@@ -69,6 +71,9 @@ public:
     virtual QPlatformSurfaceCapture *createWindowCapture(QWindowCapture *) { return nullptr; }
 
     virtual QMaybe<QPlatformAudioDecoder *> createAudioDecoder(QAudioDecoder *) { return notAvailable; }
+    virtual QMaybe<std::unique_ptr<QPlatformAudioResampler>>
+    createAudioResampler(const QAudioFormat & /*inputFormat*/,
+                         const QAudioFormat & /*outputFormat*/);
     virtual QMaybe<QPlatformMediaCaptureSession *> createCaptureSession() { return notAvailable; }
     virtual QMaybe<QPlatformMediaPlayer *> createPlayer(QMediaPlayer *) { return notAvailable; }
     virtual QMaybe<QPlatformMediaRecorder *> createRecorder(QMediaRecorder *) { return notAvailable; }
@@ -86,6 +91,10 @@ public:
 
     QPlatformCapturableWindows *capturableWindows();
 
+    QPlatformMediaDevices *mediaDevices();
+
+    static QStringList availableBackends();
+
 protected:
     virtual QPlatformMediaFormatInfo *createFormatInfo();
 
@@ -93,12 +102,7 @@ protected:
 
     virtual QPlatformCapturableWindows *createCapturableWindows() { return nullptr; }
 
-private:
-    friend class QMockIntegrationFactory;
-    // API to be able to test with a mock backend
-    using Factory = std::function<std::unique_ptr<QPlatformMediaIntegration>()>;
-    struct InstanceHolder;
-    static void setPlatformFactory(Factory factory);
+    virtual std::unique_ptr<QPlatformMediaDevices> createMediaDevices();
 
 private:
     std::unique_ptr<QPlatformVideoDevices> m_videoDevices;
@@ -109,6 +113,9 @@ private:
 
     mutable std::unique_ptr<QPlatformMediaFormatInfo> m_formatInfo;
     mutable std::once_flag m_formatInfoOnceFlg;
+
+    std::unique_ptr<QPlatformMediaDevices> m_mediaDevices;
+    std::once_flag m_mediaDevicesOnceFlag;
 };
 
 QT_END_NAMESPACE
